'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fonk = require('@lemoncode/fonk');

var VALIDATOR_TYPE = 'RANGE_DATE';
var defaultCustomArgs = {
  min: {
    value: null,
    inclusive: false
  },
  max: {
    value: null,
    inclusive: false
  },
  parseStringToDateFn: null
};
var setCustomArgs = function setCustomArgs(customArgs) {
  defaultCustomArgs = Object.assign(Object.assign({}, defaultCustomArgs), customArgs);
};
var MISSING_ARGS = 'FieldValidationError: min and max custom args are mandatory. Example: { customArgs: { min: { value: new Date() }, max: { value: new Date() } } }.';
var MISSING_PARSE_ARGS = 'FieldValidationError: parseStringToDateFn custom arg is mandatory when value is string. Example: { customArgs: { parseStringToDateFn: (value) => new Date(value) } }.';
var defaultMessage = "Date isn't included in provided range";
var setErrorMessage = function setErrorMessage(message) {
  return defaultMessage = message;
};

var isDefined = function isDefined(value) {
  return value !== void 0 && value !== null && value !== '';
};

var isString = function isString(value) {
  return typeof value === 'string';
};

var parseToDate = function parseToDate(value, _ref) {
  var parseStringToDateFn = _ref.parseStringToDateFn;

  if (!parseStringToDateFn) {
    throw new Error(MISSING_PARSE_ARGS);
  }

  return parseStringToDateFn(value);
};

var isValidMin = function isValidMin(value, min) {
  return min.inclusive ? value >= min.value : value > min.value;
};

var isValidMax = function isValidMax(value, max) {
  return max.inclusive ? value <= max.value : value < max.value;
};

var isValid = function isValid(value, customArgs) {
  return isValidMin(value, customArgs.min) && isValidMax(value, customArgs.max);
};

var hasCustomArgs = function hasCustomArgs(customArgs) {
  return customArgs && customArgs.min && customArgs.min.value && customArgs.max && customArgs.max.value;
};

var validator = function validator(_ref2) {
  var value = _ref2.value,
      _ref2$message = _ref2.message,
      message = _ref2$message === void 0 ? defaultMessage : _ref2$message,
      _ref2$customArgs = _ref2.customArgs,
      customArgs = _ref2$customArgs === void 0 ? defaultCustomArgs : _ref2$customArgs;
  var args = Object.assign(Object.assign({}, defaultCustomArgs), customArgs);

  if (!hasCustomArgs(args)) {
    throw new Error(MISSING_ARGS);
  }

  var valueAsDate = isString(value) ? parseToDate(value, args) : value;
  var succeeded = !isDefined(value) || isValid(valueAsDate, args);
  return {
    succeeded: succeeded,
    message: succeeded ? '' : fonk.parseMessageWithCustomArgs(message, args),
    type: VALIDATOR_TYPE
  };
};

var validator$1 = /*#__PURE__*/Object.freeze({
  __proto__: null,
  setCustomArgs: setCustomArgs,
  setErrorMessage: setErrorMessage,
  validator: validator
});

exports.rangeDate = validator$1;
